<?php

namespace LakeDrops\Ahoy;

use LakeDrops\Component\Composer\BaseHandler;
use LakeDrops\Component\Composer\Utils;
use Symfony\Component\Yaml\Yaml;

/**
 * Class Handler.
 *
 * @package LakeDrops\Drupal8Scaffold
 */
class Handler extends BaseHandler {

  /**
   * Update ahoy scripts of all LakeDrops plugins.
   */
  public function updateScripts() {

    // We only do the fancy stuff for developers.
    if (!$this->isDevMode()) {
      return;
    }

    $ahoy = [
      'ahoyapi' => 'v2',
      'commands' => [],
    ];

    $settings = new Utils($this->composer);
    foreach ($settings->getSubSubSection('extra', 'lakedrops', 'ahoy') as $command => $commands) {
      $ahoy['commands'][$command] = $commands;
    }

    $installationManager = $this->composer->getInstallationManager();
    foreach ($this->composer->getRepositoryManager()->getLocalRepository()->search('lakedrops/*') as $pkg) {
      $pluginRoot = $installationManager->getInstallPath($this->getPackage($pkg['name']));
      $pluginSettings = new Utils($this->composer, $pluginRoot);
      foreach ($pluginSettings->getSubSubSection('extra', 'lakedrops', 'ahoy') as $command => $commands) {
        $ahoy['commands'][$command] = $commands;
        foreach ($commands['imports'] as $key => $import) {
          $ahoy['commands'][$command]['imports'][$key] = './vendor/' . $pkg['name'] . '/' . $import;
        }
      }
    }
    $file = getcwd() . '/.ahoy.yml';
    file_put_contents($file, $rendered = Yaml::dump($ahoy, 9, 2));
    $this->gitIgnore('.ahoy.yml');
  }

}
